class meminfo:
    def __init__(self):
        self.java_heap = 0
        self.native_heap = 0
        self.code = 0
        self.stack = 0
        self.graphics = 0
        self.other = 0
        self.system = 0
        self.total = 0





import os
import re
import threading
import time

from performance import android
from performance.android import AndroidApp
from performance.log import tip


class Device(object):
    def __init__(self):
        self.series = None
        self.state = None
        self.app = None
        self.output = os.path.curdir
        self.pkg = None

    def start(self, pkg=None):
        if self.series is None or self.series == '':
            raise Exception("empty device")
        if self.state == "offline":
            raise Exception("offline device: " + self.series)

        if pkg is None:
            pkg = self.pkg

        if pkg is None or pkg == '':
            raise Exception("未指定包名.")
        assert isinstance(pkg, str)

        self.app = AndroidApp(pkg, self.series)

        # 检查app是否已经安装
        self.app.check_pkg()

        today = time.strftime("%Y-%m-%d")

        self.output = self.output + os.path.sep + today + os.path.sep + self.series
        if not os.path.isdir(self.output):
            os.makedirs(self.output)

        self.app.output = self.output

        # 清除sd卡目录下的历史crash，anr日志
        self.app.log_clear()

        try:
            monkey_thread = MonkeyThread(self.app)
            monkey_thread.setDaemon(True)
            monkey_thread.start()

            # 先清除logcat缓存
            self.app.logcat_clear()

            # 等待app启动
            tip("(%s) waiting for app start..." % self.series)
            pid = self.app.waiting_for_start()
            if pid:
                tip("(%s) app start success..." % self.series)
            else:
                tip("(%s) app start failed..." % self.series)
                raise Exception("app start failed!!!")

            logcat_thread = LogcatThread(self.app)
            logcat_thread.setDaemon(True)
            logcat_thread.start()

            logcat_e_thread = LogcatErrorThread(self.app)
            logcat_e_thread.setDaemon(True)
            logcat_e_thread.start()

            self.app.dump_memory()
        except Exception as e:
            raise e
        finally:
            self.app.stop_logcat()
            tip("(%s) process finished!!" % self.series)

    def stop(self, app=None):
        if app is None:
            app = AndroidApp(self.pkg, self.series)
        android.stop(app)


class MonkeyThread(threading.Thread):

    def __init__(self, app):
        threading.Thread.__init__(self)
        assert isinstance(app, AndroidApp)
        self.app = app

    def run(self):
        self.app.monkey()


class LogcatThread(threading.Thread):

    def __init__(self, app):
        threading.Thread.__init__(self)
        assert isinstance(app, AndroidApp)
        self.app = app

    def run(self):
        self.app.logcat()


class LogcatErrorThread(threading.Thread):

    def __init__(self, app):
        threading.Thread.__init__(self)
        assert isinstance(app, AndroidApp)
        self.app = app

    def run(self):
        self.app.logcat_e()


def get_devices():
    devices = []
    line_str = android.shell(['adb', 'devices'])
    assert isinstance(line_str, str)
    if line_str is None:
        return None
    lines = line_str.splitlines()
    for line in lines:
        device_arr = re.split("\\s+", line)
        if len(device_arr) != 2:
            continue
        device = Device()
        device.series = device_arr[0]
        device.state = device_arr[1]
        devices.append(device)
    return devices



import xlsxwriter as xlsxwriter

from performance import SHEET_NAME, COLORS


class Excel2(object):

    def __init__(self):
        self.cur_row = 1
        self.sheet = None
        self.workbook = None
        self.column_count = 0

    def create_memory_sheet(self, output, datas):
        assert isinstance(output, str)
        self.workbook = xlsxwriter.Workbook(output)
        self.sheet = self.workbook.add_worksheet(name=SHEET_NAME)
        # cell 格式类型
        # bold = self.workbook.add_format({'bold': 1})
        self.column_count = datas.__len__()
        self.sheet.write_row('A1', datas.keys())
        self.cur_row += 1
        return self.sheet

    def add_data(self, datas):
        # print("add data: " + datas)
        self.sheet.write_row('A' + str(self.cur_row), datas.values())
        self.cur_row += 1

    def create_chart(self):
        count = self.cur_row - 1
        chart = self.workbook.add_chart({'type': 'line'})
        start = 'A'
        for i in range(self.column_count):
            col = chr(ord(start) + i)
            name = '=%s!$%s$1' % (SHEET_NAME, col)
            values = '=%s!$%s$2:$%s$%d' % (SHEET_NAME, col, col, count)
            chart.add_series({
                'name': name,
                'values': values,
                'line': {'color': COLORS[i]}
            })
        chart.set_style(1)
        chart.height = 600
        chart.width = 960
        self.sheet.insert_chart("M25", chart)

    def save(self):
        self.create_chart()
        self.workbook.close()
        pass




import sys
import threading
from getopt import getopt

from performance import VERSION, android
from performance import android_device
from performance.android_device import Device
from performance.log import tip


def usage():
    pass


def version():
    return '.'.join(str(v) for v in VERSION)


def main():
    #
    devices = None
    output = None
    series = None

    hours = 10.0
    try:
        opts, args = getopt(sys.argv[1:], "o:s:t:hv")
        for op, value in opts:
            if op == '-o':
                output = value
            elif op == '-s':
                series = value
            elif op == '-h':
                usage()
                exit(0)
            elif op == '-v':
                print("pkt: " + version())
                exit(0)
            elif op == '-t':
                hours = float(value)
        pkg = args[0]
        if pkg is None:
            raise Exception("package name should not be none.")

        devices = android_device.get_devices()

        if not len(devices):
            tip("error: no devices connected !!")
            return
        for device in devices:
            if output is not None:
                device.output = output
            if series is not None and device.series == series:
                devices = [device]
                break
        device_threads = []
        for device in devices:
            assert isinstance(device, Device)
            device.pkg = pkg
            device_thread = DeviceThread(device)
            device_thread.start()
            device_threads.append(device_thread)

        for thread in device_threads:
            time_out = hours * 60 * 60
            print(time_out)
            thread.join(timeout=time_out)

    except Exception as e:
        raise e
    finally:
        if devices is None:
            return
        for device in devices:
            device.app.run = False


class DeviceThread(threading.Thread):

    def __init__(self, device):
        super().__init__()
        assert isinstance(device, Device)
        self.device = device
        self.setDaemon(False)

    def run(self):
        try:
            self.device.start()
        except Exception as e:
            print(e)
        finally:
            android.stop(self.device.app)



# -*- coding: utf-8 -*-

VERSION = [0, 0, 4]

DEBUG = False

# dump时间间隔(s)
DUMP_INTERVAL = 1

# 表单名称
SHEET_NAME = "memory"


COLORS = ['red', 'yellow', 'gray', 'blue', 'black', 'pink', '#ff34b3', '#fff8dc']



# -*- coding: utf-8 -*-
from setuptools import setup

from performance import VERSION

setup(
    name='ac-ptk',
    version='.'.join(str(v) for v in VERSION),
    url='http://appinstall.aiyoumi.com:8282/qinchao/ptk.git',
    packages=['performance'],
    author='chao',
    author_email='qinchao@aicaigroup.com',
    platforms='POSIX',
    description='android performance test kit',
    long_description="",
    keywords=(
        'android, memory, performance, auto testing'
    ),
    entry_points={
        'console_scripts': [
            'ac-ptk=performance.ptk:main',
        ],
    },
    install_requires=['xlsxwriter']
)